==> ncbi-vdb_2.8.1+dfsg.orig.tar.xz: ncbi-vdb-2.8.1/libs/kns/poll-priv.h <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#ifndef _h_poll_priv_
#define _h_poll_priv_

#ifdef __cplusplus
extern "C" {
#endif


/*--------------------------------------------------------------------------
 * forwards
 */
struct timeout_t;


/* socket_wait
 *  wait for an event or a timeout
 */
int socket_wait ( int fd, int events, struct timeout_t *tm );


#ifdef __cplusplus
}
#endif

#endif /* _h_poll_priv_ */

==> ncbi-vdb_3.2.1+dfsg.orig.tar.xz: ncbi-vdb-3.2.1/libs/kns/poll-priv.h <==
/*===========================================================================
*
*                            PUBLIC DOMAIN NOTICE
*               National Center for Biotechnology Information
*
*  This software/database is a "United States Government Work" under the
*  terms of the United States Copyright Act.  It was written as part of
*  the author's official duties as a United States Government employee and
*  thus cannot be copyrighted.  This software/database is freely available
*  to the public for use. The National Library of Medicine and the U.S.
*  Government have not placed any restriction on its use or reproduction.
*
*  Although all reasonable efforts have been taken to ensure the accuracy
*  and reliability of the software and data, the NLM and the U.S.
*  Government do not and cannot warrant the performance or results that
*  may be obtained by using this software or data. The NLM and the U.S.
*  Government disclaim all warranties, express or implied, including
*  warranties of performance, merchantability or fitness for any particular
*  purpose.
*
*  Please cite the author in any work or product based on this material.
*
* ===========================================================================
*
*/

#ifndef _h_poll_priv_
#define _h_poll_priv_

#ifdef __cplusplus
extern "C" {
#endif


/*--------------------------------------------------------------------------
 * forwards
 */
struct timeout_t;


/* socket_wait
 *  wait for an event or a timeout
 */
int socket_wait ( int fd, int events, struct timeout_t *tm );

/* connect_wait
 *  wait for a connection to become active or a timeout
 * Returns
 *  1 on success
 *  0 on timeout
 *  -1 on error (sets errno)
 */
int connect_wait ( int socketFd, int32_t timeoutMs );

#ifdef __cplusplus
}
#endif

#endif /* _h_poll_priv_ */
